pygeodesy.ltpTuples.Enu

Package pygeodesy :: Module ltpTuples :: Class Enu |
[frames] | no frames]

# Class Enu

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                            _Vector3d --+
                                        |
                                 XyzLocal --+
                                            |
                                           Enu

Local `Eeast-North-Up` (ENU) location in a local tangent plane.

See Also: East, North, Up (ENU) coordinates.

Instance Methods
__init__(self, east_enu, north=0, up=0, ltp=None, **name) New Enu. |
toUvw(self, location, Uvw=None, **name_Uvw_kwds) Get the u, v, w (UVW) components at a location. |
Inherited from `XyzLocal`: `__str__`, `classof`, `toAer`, `toCartesian`, `toEnu`, `toLatLon`, `toLocal9Tuple`, `toNed`, `toXyz` Inherited from `_Vector3d`: `toRepr`, `toStr` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__` Inherited from `named._Named`: `__format__`, `attrs`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| xyzLocal Get this ENU as an XyzLocal.
Inherited from `XyzLocal`: `aer4`, `azimuth`, `down`, `east`, `ecef`, `elevation`, `enu4`, `groundrange`, `ltp`, `ned4`, `north`, `slantrange`, `up`, `xyz4` Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, east_enu, north=0, up=0, ltp=None, **name) (Constructor) |
New Enu. Arguments: `east_enu` - Scalar East component (`meter`) or a previous local instance (Enu, Enu4Tuple, Aer, Aer4Tuple, Local9Tuple, Ned, Ned4Tuple, XyzLocal or Xyz4Tuple). `north` - Scalar North component (`meter`), iff `east_enu` is `meter`, ignored otherwise. `up` - Scalar Up component (`meter`, normal from the surface of the ellipsoid or sphere), iff `east_enu` is `meter`, ignored otherwise. `ltp` - The local tangent plane, (geodetic) origin (Ltp, LocalCartesian). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `east_enu` or `ltp`. `UnitError` - Invalid `east_enu`, `north` or `up`. Overrides: object.__init__

### toUvw (self, location, Uvw=None, **name_Uvw_kwds) |
Get the u, v, w (UVW) components at a location. Arguments: `location` - The geodetic (`LatLon`) or geocentric (`Cartesian`, Vector3d) location, like a Point-Of-View. `Uvw` - Class to return UWV (Uvw) or `None`. `name_Uvw_kwds` - Optional `name=NN` (`str`) and optionally, additional Uvw keyword arguments, ignored if `Uvw is None`. Returns: A `Uvw` instance or a Uvw3Tuple`(u, v, w)` if `Uvw is None`. Raises: `TypeError` - Invalid `location` or `name_Uvw_kwds` item. See Also: Function lookAtSpheroid.

Property Details

### xyzLocal Get this ENU as an XyzLocal. Get method: xyzLocal(self) - Get this ENU as an XyzLocal. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.